@@ -180,7 +180,10 @@ class RichOptionPanel(RichPanel[Parameter, OptionColumnType]):
 
     @classmethod
     def list_all_objects(cls, ctx: Context) -> List[Tuple[str, Parameter]]:
-        return [(i.name, i) for i in ctx.command.get_params(ctx)]  # type: ignore[misc]
+        return [
+            (i.opts[0] if getattr(i, "flag_value", None) and i.opts else i.name, i)  # type: ignore[misc]
+            for i in ctx.command.get_params(ctx)
+        ]
 
     def get_objects(self, command: Command, ctx: Context) -> Generator[Parameter, None, None]:
         """List the objects assigned to the panel."""
